smartcard.Observer.Observer

# ``smartcard`.`Observer`.`Observer``

class documentation

`class Observer(object):`

Known subclasses: `smartcard.CardConnectionObserver.CardConnectionObserver`, `smartcard.CardMonitoring.CardObserver`, `smartcard.ReaderMonitoring.ReaderObserver`

View In Hierarchy

Undocumented

Method | `update` | Called when the observed object is modified. You call an Observable object's notifyObservers method to notify all the object's observers of the change.

def update(observable, arg):
overridden in `smartcard.CardConnectionObserver.CardConnectionObserver`, `smartcard.CardMonitoring.CardObserver`, `smartcard.ReaderMonitoring.ReaderObserver`

Called when the observed object is modified. You call an Observable object's notifyObservers method to notify all the object's observers of the change.